==> zio-aws-serverlessapplicationrepository_2.13-5.17.162.1-sources.jar: zio/aws/serverlessapplicationrepository/model/ListApplicationVersionsResponse.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class ListApplicationVersionsResponse(
    nextToken: Optional[__string] = Optional.Absent,
    versions: Optional[
      Iterable[zio.aws.serverlessapplicationrepository.model.VersionSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse = {
    import ListApplicationVersionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        versions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.versions)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse
      .wrap(buildAwsValue())
}
object ListApplicationVersionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse =
      zio.aws.serverlessapplicationrepository.model
        .ListApplicationVersionsResponse(
          nextToken.map(value => value),
          versions.map(value =>
            value.map { item =>
              item.asEditable
            }
          )
        )
    def nextToken: Optional[__string]
    def versions: Optional[List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]]
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getVersions: ZIO[Any, AwsError, List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("versions", versions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ) extends zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly {
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
    override val versions: Optional[List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.versions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.serverlessapplicationrepository.model.VersionSummary
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ): zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_3-5.17.104.7-sources.jar: zio/aws/serverlessapplicationrepository/model/ListApplicationVersionsResponse.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class ListApplicationVersionsResponse(
    nextToken: Option[__string] = None,
    versions: Option[
      Iterable[zio.aws.serverlessapplicationrepository.model.VersionSummary]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse = {
    import ListApplicationVersionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
      .builder()
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        versions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.versions)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse
      .wrap(buildAwsValue())
}
object ListApplicationVersionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse =
      zio.aws.serverlessapplicationrepository.model
        .ListApplicationVersionsResponse(
          nextToken.map(value => value),
          versions.map(value =>
            value.map { item =>
              item.asEditable
            }
          )
        )
    def nextToken: Option[__string]
    def versions: Option[List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]]
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getVersions: ZIO[Any, AwsError, List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("versions", versions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ) extends zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly {
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.serverlessapplicationrepository.model.primitives.__string(value)
      )
    override val versions: Option[List[
      zio.aws.serverlessapplicationrepository.model.VersionSummary.ReadOnly
    ]] = scala
      .Option(impl.versions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.serverlessapplicationrepository.model.VersionSummary
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.ListApplicationVersionsResponse
  ): zio.aws.serverlessapplicationrepository.model.ListApplicationVersionsResponse.ReadOnly =
    new Wrapper(impl)
}
